Useful References
=================

A collection of links for learning more about Python and other tools used by
PySB.

Python Language
--------------- 

For those unfamiliar with Python or programming there are several
resources available online. We have found the ones below useful to
learn Python in a practical and straightfoward manner.

Quick Python Overview: 
   * `Instant Python <http://hetland.org/writing/instant-python.html>`_

Python tutorials for beginners, experienced users, or if you want a refresher:
   * `Official Python tutorial <http://docs.python.org/tutorial/>`_
   * `Python for non-programmers <http://wiki.python.org/moin/BeginnersGuide/NonProgrammers>`_
   * `Dive into Python <http://www.diveintopython.net/>`_
   * `Thinking in Python <http://www.mindview.net/Books/TIPython>`_

NumPy and SciPy
---------------

NumPy:
   * `NumPy for Matlab <http://www.scipy.org/NumPy_for_Matlab_Users/>`_
   * Also the
     `Mathesaurus <http://mathesaurus.sourceforge.net/matlab-numpy.html>`_
   * Matlab commands in Numerical Python
     `cheatsheet <http://mathesaurus.sourceforge.net/matlab-python-xref.pdf>`_

SciPy:
   * `Scientific Python <http://www.scipy.org/>`_

BioNetGen
---------

* `BioNetGen tutorial <http://bionetgen.org/index.php/BioNetGen_Tutorial>`_
* `Compartmental BNGL <http://bionetgen.org/index.php/Compartments_in_BNGL>`_

